#include <stdlib.h>
#include <assert.h>
#include <Eina.h>
#include <Ecore.h>
#include <Evas.h>
#include <Elementary.h>

#define _INSTALL_DIR "./"

#define DEFAULT_THEME_EDJE_PATH _INSTALL_DIR "themes/evas_test.edj"

static Eina_Bool
_timer_cb(void *data)
{
   Evas_Object *layout = data;
   int x, y;

   printf("\n\n\n*** TIMER CALLED ***\n");

   if (!layout) return ECORE_CALLBACK_CANCEL;

   evas_object_geometry_get(layout, &x, &y, NULL, NULL);
   evas_object_move(layout, x + 20, y + 20);

   return ECORE_CALLBACK_RENEW;
}

int
main(int argc EINA_UNUSED, char **argv EINA_UNUSED)
{
   Ecore_Evas *ee;
   Evas *e;
   Evas_Object *win, *layout, *icon, *rect, *proxy;
   Eina_Bool retval;
   Ecore_Timer *timer;

   eina_init();
   evas_init();
   ecore_evas_init();
   ecore_init();
   edje_init();
   ee = ecore_evas_new(NULL, 0, 0, 300, 300, NULL);
   e = ecore_evas_get(ee);
   if (!e)
     {
        printf("ERR: Could not create Evas.\n");
        return -1;
     }

   // bg
   rect = evas_object_rectangle_add(e);
   evas_object_resize(rect, 300, 300);
   evas_object_color_set(rect, 128, 128, 128, 255);
   evas_object_move(rect, 0, 0);
   evas_object_show(rect);

   // edje object (smart object, that will be the source for proxy)
   layout = edje_object_add(e);
   retval = edje_object_file_set(layout, DEFAULT_THEME_EDJE_PATH,
                        "test_group");

   assert(retval != EINA_FALSE);
   evas_object_resize(layout, 150, 150);
   evas_object_move(layout, -130, -130);
   evas_object_raise(layout);

   evas_object_show(layout);

   // proxy object
   proxy = evas_object_image_filled_add(e);
   evas_object_resize(proxy, 200, 200);
   evas_object_move(proxy, 100, 100);
   evas_object_image_source_set(proxy, layout);
   evas_object_show(proxy);


   // timer that will move the source object
   timer = ecore_timer_add(3.0, _timer_cb, layout);

   // elm_run();
   ecore_evas_show(ee);

   ecore_main_loop_begin();

   return 0;
}
